<?php

//$X = 173182.829000004;
//$Y = 120426.445;

//$resultat=LB72toWGS84($X,$Y);

//print_r ("\nRésultat: ");
//print_r ($resultat);

function LB72toWGS84($X,$Y)
{

$retour = array();

// Belgian Lambert 72 to spherical coordinates

//       Belgian Lambert 1972---> Spherical coordinates
//       Input parameters : X, Y = Belgian coordinates in meters
//       Output : latitude and longitude in Belgium Datum!

$LongRef = 0.076042943;        // =4°21'24"983
$nLamb   = 0.7716421928;
$aCarre  = pow(6378388,2);
$bLamb   = 6378388 * (1 - (1 / 297));
$eCarre  = ($aCarre - pow($bLamb,2) ) / $aCarre;
$KLamb   = 11565915.812935;
 
$eLamb   = sqrt($eCarre);
$eSur2   = $eLamb / 2;
 
$Tan1    = ($X - 150000.01256) / (5400088.4378 - $Y);
$Lambda  = $LongRef + (1 / $nLamb) * (0.000142043 + atan($Tan1));
$RLamb   = sqrt(pow(($X - 150000.01256),2) + pow((5400088.4378 - $Y),2) );

$TanZDemi= ($RLamb / $KLamb) ** (1 / $nLamb);
$Lati1   = 2 * atan($TanZDemi);

do
 {
    $eSin = $eLamb * sin($Lati1);
    $Mult1 = 1 - $eSin;
    $Mult2 = 1 + $eSin;
    $Mult = ($Mult1 / $Mult2) ** ($eLamb / 2);
    $LatiN = (pi() / 2) - (2 * (atan($TanZDemi * $Mult)));
    $Diff = $LatiN - $Lati1;
    $Lati1 = $LatiN;
 } while (abs($Diff) > 0.0000000277777);
 
$Lat = ($LatiN * 180) / pi();
$Lng = ($Lambda * 180) / pi();

$retour[0]=$Lat;
$retour[1]=$Lng;

//print_r ("\nLat: ".$Lat);
//print_r ("\nLng: ".$Lng);


// Belgian Datum to WGS84 conversion (Molodensky 3 parameters)

// Input parameters : Lat, Lng : latitude / longitude in decimal degrees and in Belgian 1972 datum
// Output parameters : LatWGS84, LngWGS84 : latitude / longitude in decimal degrees and in WGS84 datum

$Haut = 0;      // Altitude

// conversion to radians
$Lat = (pi() / 180) * $Lat;
$Lng = (pi() / 180) * $Lng;
 
$SinLat = sin($Lat);
$SinLng = sin($Lng);
$CoSinLat = cos($Lat);
$CoSinLng = cos($Lng);
 
$dx = -125.8;
$dy = 79.9;
$dz = -100.5;
$da = -251.0;
$df = -0.000014192702;

$LWf = 1 / 297;
$LWa = 6378388;
$LWb = (1 - $LWf) * $LWa;
$LWe2 = (2 * $LWf) - ($LWf * $LWf);
$Adb = 1 / (1 - $LWf);

$Rn = $LWa / sqrt(1 - $LWe2 * $SinLat * $SinLat);
$Rm = $LWa * (1 - $LWe2) / (1 - $LWe2 * $Lat * $Lat) ** 1.5;
 
$DLat = -$dx * $SinLat * $CoSinLng - $dy * $SinLat * $SinLng + $dz * $CoSinLat;
$DLat = $DLat + $da * ($Rn * $LWe2 * $SinLat * $CoSinLat) / $LWa;
$DLat = $DLat + $df * ($Rm * $Adb + $Rn / $Adb) * $SinLat * $CoSinLat;
$DLat = $DLat / ($Rm + $Haut);

$DLng = (-$dx * $SinLng + $dy * $CoSinLng) / (($Rn + $Haut) * $CoSinLat);
$Dh = $dx * $CoSinLat * $CoSinLng + $dy * $CoSinLat * $SinLng + $dz * $SinLat;
$Dh = $Dh - $da * $LWa / $Rn + $df * $Rn * $Lat * $Lat / $Adb;

$LatWGS84 = (($Lat + $DLat) * 180) / pi();
$LngWGS84 = (($Lng + $DLng) * 180) / pi();

//print_r ("\nLatWGS84: ".$LatWGS84);
//print_r ("\nLngWGS84: ".$LngWGS84);
//print ("\n");

$retour[2]=$LatWGS84;
$retour[3]=$LngWGS84;

return ($retour);

}

?>
